@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Generator, Type, TypeVar
+from typing import TYPE_CHECKING, Generator, TypeVar
 
 from tsbot import utils
 
@@ -24,13 +24,20 @@ class TSResponse:
         """Returns the first datapoint from the response"""
         return self.data[0]
 
+    @property
+    def last(self) -> dict[str, str]:
+        """Returns the last datapoint from the response"""
+        return self.data[-1]
+
     @classmethod
-    def from_server_response(cls: Type[T], raw_data: list[str]) -> T:
-        error_id, msg = parse_error_line(raw_data.pop())
+    def from_server_response(cls: type[T], raw_data: list[str]) -> T:
+        response_info = utils.parse_line(raw_data.pop().removeprefix("error "))
         data = utils.parse_data("".join(raw_data))
+
+        error_id = int(response_info.pop("id"))
+        msg = response_info.pop("msg")
+
+        if response_info:
+            data.append(response_info)
+
         return cls(data=data, error_id=error_id, msg=msg)
-
-
-def parse_error_line(input_str: str) -> tuple[int, str]:
-    data = utils.parse_line(input_str)
-    return int(data["id"]), data["msg"]
